==> restful-1.36.47-Final-sources.jar: com/aote/config/SystemConfig.java <==
package com.aote.config;

import com.aote.exception.FileNotFoundException;
import com.aote.util.other.JsonTools;
import org.apache.log4j.Logger;
import org.json.JSONArray;
import org.json.JSONObject;

/**
 * 系统配置
 *
 * @author Mr.river
 */
public class SystemConfig {
    private static final Logger LOGGER = Logger.getLogger(SystemConfig.class);

    private static final String CONFIG_PATH = "systemConfig.json";

    private static boolean isLoaded = false;

    /**
     * 获取配置文件并加载
     */
    private static void load() {
        //获取配置文件
        if(!isLoaded){
            isLoaded = true;
            if (SystemConfig.class.getClassLoader().getResource(CONFIG_PATH) != null) {
                JSONObject params = JsonTools.readJsonFile(CONFIG_PATH);
                /* 系统配置 **/
                JSONObject system = params.getJSONObject("system");
                if(!system.has("webAppName")){
                    throw new RuntimeException(CONFIG_PATH+"中服务应用模块名参数[system:webAppName]不存在，请配置该参数为web应用名称，如revenue,webmeter等");
                }
                System.webAppName = system.getString("webAppName");
                /* 日志持久化配置 **/
                JSONObject persistenceLog = params.getJSONObject("persistenceLog");
                PersistenceLog.isEnabled = persistenceLog.optBoolean("isEnabled", false);
                if(PersistenceLog.isEnabled){
                    LOGGER.info("异常日志持久化记录已开启，如需关闭，请将"+CONFIG_PATH+"中[persistenceLog:isEnabled]配置为false.");
                } else {
                    LOGGER.warn("异常日志持久化记录已关闭，如需开启，请将"+CONFIG_PATH+"中[persistenceLog:isEnabled]配置为true.");
                }
                /* Redis配置 **/
                JSONObject redis = params.getJSONObject("redis");
                Redis.hostName = redis.optString("hostName", null);
                Redis.password = redis.optString("password", null);
                /* 资源类配置 **/
                JSONObject resources = params.getJSONObject("resources");
                if(!resources.has("fileRootPath")){
                    LOGGER.warn(CONFIG_PATH + "中资源根目录参数[resources:fileRootPath]不存在，以按照缺省值[D:/"+ System.webAppName + "Res]配置");
                }
                Resources.fileRootPath = resources.optString("fileRootPath", "D:/" + System.webAppName + "Res");
                //  如果有扩展目录配置，则追加
                if(resources.has("extraPaths")){
                    Resources.extraPaths = resources.getJSONObject("extraPaths");
                }
                /* 实体映射配置 **/
                SubClass.subClassArray = params.optJSONArray("subclass");
            } else {
                throw new FileNotFoundException("系统配置文件"+CONFIG_PATH+"不存在", CONFIG_PATH);
            }
        }
    }

    /**
     * 系统
     */
    public static class System {

        private static String webAppName;

        static {
            SystemConfig.load();
        }

        public static String getWebAppName() {
            return webAppName;
        }
    }

    /**
     * 日志持久化
     */
    public static class PersistenceLog {
        private static Boolean isEnabled;

        static {
            SystemConfig.load();
        }

        public static Boolean getEnabled() {
            return isEnabled;
        }
    }

    /**
     * Redis
     */
    public static class Redis {
        private static String hostName;
        private static String password;

        static {
            SystemConfig.load();
        }

        public static String getHostName() {
            return hostName;
        }
        public static boolean hasHostName() {
            return hostName != null;
        }
        public static String getPassword() {
            return password;
        }
        public static boolean hasPassword() {
            return password != null;
        }
    }

    /**
     * 资源
     */
    public static class Resources {
        private static String fileRootPath;
        private static JSONObject extraPaths;

        static {
            SystemConfig.load();
        }

        public static String getFileRootPath() {
            return fileRootPath;
        }

        public static String getExtraPath(String key) {
            return extraPaths.getString(key);
        }
    }

    /**
     * 实体映射
     */
    public static class SubClass {
        private static JSONArray subClassArray;

        static {
            SystemConfig.load();
        }

        public static JSONArray getSubClassArray() {
            return subClassArray;
        }
        public static boolean hasSubClassArray() {
            return subClassArray != null;
        }
    }
}

==> restful-1.36.62-Final-sources.jar: com/aote/config/SystemConfig.java <==
package com.aote.config;

import com.aote.exception.FileNotFoundException;
import com.aote.util.other.JsonTools;
import org.apache.log4j.Logger;
import org.json.JSONArray;
import org.json.JSONObject;

/**
 * 系统配置
 *
 * @author Mr.river
 */
public class SystemConfig {
    private static final Logger LOGGER = Logger.getLogger(SystemConfig.class);

    private static final String CONFIG_PATH = "systemConfig.json";

    private static boolean isLoaded = false;

    /**
     * 获取配置文件并加载
     */
    private static void load() {
        //获取配置文件
        if(!isLoaded){
            isLoaded = true;
            if (SystemConfig.class.getClassLoader().getResource(CONFIG_PATH) != null) {
                JSONObject params = JsonTools.readJsonFile(CONFIG_PATH);
                /* 系统配置 **/
                JSONObject system = params.getJSONObject("system");
                if(!system.has("webAppName")){
                    throw new RuntimeException(CONFIG_PATH+"中服务应用模块名参数[system:webAppName]不存在，请配置该参数为web应用名称，如revenue,webmeter等");
                }
                System.webAppName = system.getString("webAppName");
                SaleVersionEnum saleVersionEnum;
                if(!system.has("saleVersion")){
                    LOGGER.warn(CONFIG_PATH+"中服务应用模块名参数[system:saleVersion]不存在，默认为Vue-V3.");
                    saleVersionEnum = SaleVersionEnum.Vue_V3;
                } else {
                    saleVersionEnum = SaleVersionEnum.toType(system.getString("saleVersion"));
                    if(saleVersionEnum == null){
                        throw new RuntimeException(CONFIG_PATH+"中服务应用模块名参数[system:saleVersion]配置有误，不存在的值：" + system.getString("saleVersion"));
                    }
                }
                System.saleVersion = saleVersionEnum;
                /* 日志持久化配置 **/
                JSONObject persistenceLog = params.getJSONObject("persistenceLog");
                PersistenceLog.isEnabled = persistenceLog.optBoolean("isEnabled", false);
                if(PersistenceLog.isEnabled){
                    LOGGER.info("异常日志持久化记录已开启，如需关闭，请将"+CONFIG_PATH+"中[persistenceLog:isEnabled]配置为false.");
                } else {
                    LOGGER.warn("异常日志持久化记录已关闭，如需开启，请将"+CONFIG_PATH+"中[persistenceLog:isEnabled]配置为true.");
                }
                /* Redis配置 **/
                JSONObject redis = params.getJSONObject("redis");
                Redis.hostName = redis.optString("hostName", null);
                Redis.password = redis.optString("password", null);
                /* 资源类配置 **/
                JSONObject resources = params.getJSONObject("resources");
                if(!resources.has("fileRootPath")){
                    LOGGER.warn(CONFIG_PATH + "中资源根目录参数[resources:fileRootPath]不存在，以按照缺省值[D:/"+ System.webAppName + "Res]配置");
                }
                Resources.fileRootPath = resources.optString("fileRootPath", "D:/" + System.webAppName + "Res");
                //  如果有扩展目录配置，则追加
                if(resources.has("extraPaths")){
                    Resources.extraPaths = resources.getJSONObject("extraPaths");
                }
                /* 实体映射配置 **/
                SubClass.subClassArray = params.optJSONArray("subclass");
            } else {
                throw new FileNotFoundException("系统配置文件"+CONFIG_PATH+"不存在", CONFIG_PATH);
            }
        }
    }

    /**
     * 系统
     */
    public static class System {

        private static String webAppName;

        private static SaleVersionEnum saleVersion;

        static {
            SystemConfig.load();
        }

        public static String getWebAppName() {
            return webAppName;
        }

        public static SaleVersionEnum saleVersion() {
            return saleVersion;
        }
    }

    /**
     * 日志持久化
     */
    public static class PersistenceLog {
        private static Boolean isEnabled;

        static {
            SystemConfig.load();
        }

        public static Boolean getEnabled() {
            return isEnabled;
        }
    }

    /**
     * Redis
     */
    public static class Redis {
        private static String hostName;
        private static String password;

        static {
            SystemConfig.load();
        }

        public static String getHostName() {
            return hostName;
        }
        public static boolean hasHostName() {
            return hostName != null;
        }
        public static String getPassword() {
            return password;
        }
        public static boolean hasPassword() {
            return password != null;
        }
    }

    /**
     * 资源
     */
    public static class Resources {
        private static String fileRootPath;
        private static JSONObject extraPaths;

        static {
            SystemConfig.load();
        }

        public static String getFileRootPath() {
            return fileRootPath;
        }

        public static String getExtraPath(String key) {
            return extraPaths.getString(key);
        }
    }

    /**
     * 实体映射
     */
    public static class SubClass {
        private static JSONArray subClassArray;

        static {
            SystemConfig.load();
        }

        public static JSONArray getSubClassArray() {
            return subClassArray;
        }
        public static boolean hasSubClassArray() {
            return subClassArray != null;
        }
    }
}
